<?php 

/**
 * Init theme options
 * Certain theme options need to be written to the database as soon as the theme is installed.
 * This is either for the enqueues in ebor-framework, or to override the default image sizes in WooCommerce.
 * Either way this function is only called when the theme is first activated, de-activating and re-activating the theme will result in these options returning to defaults.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_init_theme_options') )){
	
	/**
	 * Hook in on activation
	 */
	global $pagenow;
	
	/**
	 * Define image sizes
	 */
	function ebor_init_theme_options() {
		
		//Set all options to zero before initialising options for this theme
		$existing_options = get_option('ebor_framework_options');
		if( is_array($existing_options) ){
			foreach ($existing_options as $key => $value) {
				$existing_options[$key] = '0';
			}
			update_option('ebor_framework_options', $existing_options);
		}
		
		//Ebor Framework
		$framework_args = array(
			'portfolio_post_type'     => '1',
			'team_post_type'          => '1',
			'options'                 => '1',
			'sugarland_vc_shortcodes' => '1'
		);
		update_option('ebor_framework_options', $framework_args);
		
	}
	
	/**
	 * Only call this action when we first activate the theme.
	 */
	if ( 
		is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ||
		is_admin() && isset( $_GET['theme'] ) && $pagenow == 'customize.php'
	){
		add_action( 'after_setup_theme', 'ebor_init_theme_options', 1 );
	}
	
}

/**
 * Register the required plugins for this theme.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_register_required_plugins') )){
	function ebor_register_required_plugins() {
		$plugins = array(
			array(
			    'name'      => esc_html__('Contact Form 7', 'sugarland'),
			    'slug'      => 'contact-form-7',
			    'required'  => false,
			    'version' 	=> '3.7.2'
			),
			array(
			    'name'      => esc_html__('Custom Metaboxes 2', 'sugarland'),
			    'slug'      => 'cmb2',
			    'required'  => true,
			    'version' 	=> '1.0.0'
			),
			array(
			    'name'      => esc_html__('One Click Demo Import', 'sugarland'),
			    'slug'      => 'one-click-demo-import',
			    'required'  => false,
			    'version' 	=> '1.0.0'
			),
			array(
				'name'     				=> esc_html__('Ebor Framework', 'sugarland'),
				'slug'     				=> 'Ebor-Framework-master',
				'source'   				=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
				'required' 				=> true,
				'version' 				=> '1.3.5',
				'external_url' 			=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
			),
			array(
				'name'     				=> esc_html__('Visual Composer', 'sugarland'),
				'slug'     				=> 'js_composer',
				'source'   				=> 'http://www.madeinebor.com/plugin-downloads/js_composer-latest.zip',
				'required' 				=> false,
				'external_url' 			=> 'http://www.madeinebor.com/plugin-downloads/js_composer-latest.zip',
				'version' 				=> '5.2.1',
			)
		);
		$config = array(
			'is_automatic' => true,
		);
		tgmpa( $plugins, $config );
	}
	add_action( 'tgmpa_register', 'ebor_register_required_plugins' );
}

if(!( function_exists('ebor_pagination') )){
	function ebor_pagination($pages = '', $range = 2){
		$showitems = ($range * 2)+1;
		
		global $paged;
		if(empty($paged)) $paged = 1;
		
		if($pages == ''){
			global $wp_query;
			$pages = $wp_query->max_num_pages;
				if(!$pages) {
					$pages = 1;
				}
		}
		
		$output = '';
			
		if(1 != $pages){	
			$output .= '<div class="container clearfix no-header"><div class="clearfix col-lg-12 centered"><ul class="pagination clearfix">';		
			for ($i=1; $i <= $pages; $i++){
				if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )){
					$output .= ($paged == $i)? "<li><a class='active' href='".get_pagenum_link($i)."'>".$i."</a></li>":"<li><a href='".get_pagenum_link($i)."'>".$i."</a></li>";
				}
			}
			$output .= '</ul></div></div>';
		}
		
		return $output;
	}
}

function ebor_get_social_icons(){
	return array(
		"socicon-500px" => "500px","socicon-8tracks" => "8tracks","socicon-airbnb" => "Airbnb","socicon-alliance" => "Alliance","socicon-amazon" => "Amazon","socicon-amplement" => "Amplement","socicon-android" => "Android","socicon-angellist" => "Angellist","socicon-apple" => "Apple","socicon-appnet" => "Appnet","socicon-baidu" => "Baidu","socicon-bandcamp" => "Bandcamp","socicon-battlenet" => "Battlenet","socicon-beam" => "Beam","socicon-bebee" => "Bebee","socicon-bebo" => "Bebo","socicon-behance" => "Behance","socicon-blizzard" => "Blizzard","socicon-blogger" => "Blogger","socicon-bloglovin" => "Bloglovin","socicon-buffer" => "Buffer","socicon-chrome" => "Chrome","socicon-coderwall" => "Coderwall","socicon-curse" => "Curse","socicon-dailymotion" => "Dailymotion","socicon-deezer" => "Deezer","socicon-delicious" => "Delicious","socicon-deviantart" => "Deviantart","socicon-diablo" => "Diablo","socicon-digg" => "Digg","socicon-discord" => "Discord","socicon-disqus" => "Disqus","socicon-douban" => "Douban","socicon-draugiem" => "Draugiem","socicon-dribbble" => "Dribbble","socicon-drupal" => "Drupal","socicon-ebay" => "Ebay","socicon-ello" => "Ello","socicon-endomodo" => "Endomodo","socicon-envato" => "Envato","socicon-etsy" => "Etsy","socicon-facebook" => "Facebook","socicon-feedburner" => "Feedburner","socicon-filmweb" => "Filmweb","socicon-firefox" => "Firefox","socicon-flattr" => "Flattr","socicon-flickr" => "Flickr","socicon-formulr" => "Formulr","socicon-forrst" => "Forrst","socicon-foursquare" => "Foursquare","socicon-friendfeed" => "Friendfeed","socicon-gamejolt" => "Gamejolt","socicon-gamewisp" => "Gamewisp","socicon-github" => "Github","socicon-goodreads" => "Goodreads","socicon-google" => "Google","socicon-googlegroups" => "Googlegroups","socicon-googlephotos" => "Googlephotos","socicon-googleplus" => "Googleplus","socicon-googlescholar" => "Googlescholar","socicon-grooveshark" => "Grooveshark","socicon-hackerrank" => "Hackerrank","socicon-hearthstone" => "Hearthstone","socicon-hellocoton" => "Hellocoton","socicon-heroes" => "Heroes","socicon-hitbox" => "Hitbox","socicon-horde" => "Horde","socicon-houzz" => "Houzz","socicon-icq" => "Icq","socicon-identica" => "Identica","socicon-imdb" => "Imdb","socicon-instagram" => "Instagram","socicon-issuu" => "Issuu","socicon-istock" => "Istock","socicon-itunes" => "Itunes","socicon-keybase" => "Keybase","socicon-lanyrd" => "Lanyrd","socicon-lastfm" => "Lastfm","socicon-line" => "Line","socicon-linkedin" => "Linkedin","socicon-livejournal" => "Livejournal","socicon-lyft" => "Lyft","socicon-macos" => "Macos","socicon-mail" => "Mail","socicon-medium" => "Medium","socicon-meetup" => "Meetup","socicon-mixcloud" => "Mixcloud","socicon-modelmayhem" => "Modelmayhem","socicon-mumble" => "Mumble","socicon-myspace" => "Myspace","socicon-newsvine" => "Newsvine","socicon-nintendo" => "Nintendo","socicon-npm" => "Npm","socicon-odnoklassniki" => "Odnoklassniki","socicon-openid" => "Openid","socicon-opera" => "Opera","socicon-outlook" => "Outlook","socicon-overwatch" => "Overwatch","socicon-patreon" => "Patreon","socicon-paypal" => "Paypal","socicon-periscope" => "Periscope","socicon-persona" => "Persona","socicon-pinterest" => "Pinterest","socicon-play" => "Play","socicon-player" => "Player","socicon-playstation" => "Playstation","socicon-pocket" => "Pocket","socicon-qq" => "Qq","socicon-quora" => "Quora","socicon-raidcall" => "Raidcall","socicon-ravelry" => "Ravelry","socicon-reddit" => "Reddit","socicon-renren" => "Renren","socicon-researchgate" => "Researchgate","socicon-residentadvisor" => "Residentadvisor","socicon-reverbnation" => "Reverbnation","socicon-rss" => "Rss","socicon-sharethis" => "Sharethis","socicon-skype" => "Skype","socicon-slideshare" => "Slideshare","socicon-smugmug" => "Smugmug","socicon-snapchat" => "Snapchat","socicon-songkick" => "Songkick","socicon-soundcloud" => "Soundcloud","socicon-spotify" => "Spotify","socicon-spreadshirt" => "Spreadshirt","socicon-stackexchange" => "Stackexchange","socicon-stackoverflow" => "Stackoverflow","socicon-starcraft" => "Starcraft","socicon-stayfriends" => "Stayfriends","socicon-steam" => "Steam","socicon-storehouse" => "Storehouse","socicon-strava" => "Strava","socicon-streamjar" => "Streamjar","socicon-stumbleupon" => "Stumbleupon","socicon-swarm" => "Swarm","socicon-teamspeak" => "Teamspeak","socicon-teamviewer" => "Teamviewer","socicon-technorati" => "Technorati","socicon-telegram" => "Telegram","socicon-trello" => "Trello","socicon-tripadvisor" => "Tripadvisor","socicon-tripit" => "Tripit","socicon-triplej" => "Triplej","socicon-tumblr" => "Tumblr","socicon-tunein" => "Tunein","socicon-twitch" => "Twitch","socicon-twitter" => "Twitter","socicon-uber" => "Uber","socicon-ventrilo" => "Ventrilo","socicon-viadeo" => "Viadeo","socicon-viber" => "Viber","socicon-viewbug" => "Viewbug","socicon-vimeo" => "Vimeo","socicon-vine" => "Vine","socicon-vkontakte" => "Vkontakte","socicon-warcraft" => "Warcraft","socicon-wechat" => "Wechat","socicon-weibo" => "Weibo","socicon-whatsapp" => "Whatsapp","socicon-wikipedia" => "Wikipedia","socicon-windows" => "Windows","socicon-wordpress" => "Wordpress","socicon-wykop" => "Wykop","socicon-xbox" => "Xbox","socicon-xing" => "Xing","socicon-yahoo" => "Yahoo","socicon-yammer" => "Yammer","socicon-yandex" => "Yandex","socicon-yelp" => "Yelp","socicon-younow" => "Younow","socicon-youtube" => "Youtube","socicon-zapier" => "Zapier","socicon-zerply" => "Zerply","socicon-zomato" => "Zomato","socicon-zynga" => "Zynga"
	);
}

if(!( function_exists('ebor_get_icons') )){
	function ebor_get_icons(){
		return array(
			'none' => 'None',
			'facebook' => 'Facebook',
			'dribbble' => 'Dribbble',
			'behance' => 'Behance',
			'git' => 'GitHub',
			'google-plus' => 'Google+',
			'xing' => 'Xing',
			'instagram' => 'Instagram',
			'twitter' => 'Twitter',
			'youtube' => 'Youtube',
			'slack' => 'Slack',
			'pinterest' => 'Pinterest',
			'tumblr' => 'Tumblr',
			'soundcloud' => 'Soundcloud',
			'skype' => 'Skype',
			'linkedin' => 'LinkedIn',
			'vimeo' => 'Vimeo',
			'flickr' => 'Flickr',
			'vk' => 'VK',
			'500px' => '500px',
			'email' => 'Email'
		);
	}
}

if(!( function_exists('tommusrhodus_easy_menu_per_page_override_menu') )){
	function tommusrhodus_easy_menu_per_page_override_menu($args = ''){
		global $post;
	
		if( isset($post->ID) && isset($args['theme_location']) && 'primary' == $args['theme_location'] ){
			$override = get_post_meta($post->ID, '_tommusrhodus_easy_menu_per_page_menu_override', 1);
			if(!( 'none' ==  $override || false == $override || '' == $override )){
				if( is_nav_menu($override) ){
					$args['menu'] = $override;
				}	
			}
		}
		
		return $args;
			
	}
	add_filter('wp_nav_menu_args', 'tommusrhodus_easy_menu_per_page_override_menu', 99);
}

if(!( function_exists('tommusrhodus_easy_menu_per_page_custom_metaboxes') )){
	function tommusrhodus_easy_menu_per_page_custom_metaboxes( $meta_boxes ) {
		$prefix = '_tommusrhodus_easy_menu_per_page_';
		
		$custom_menus = array();
		$custom_menus['none'] = 'Do Not Override Menu On This Page';
		$menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
		if ( is_array( $menus ) && ! empty( $menus ) ) {
			foreach ( $menus as $single_menu ) {
				if ( is_object( $single_menu ) && isset( $single_menu->name, $single_menu->slug ) ) {
					$custom_menus[ $single_menu->slug ] = $single_menu->name;
				}
			}
		}

		$meta_boxes[] = array(
			'id' => 'tommusrhodus_easy_menu_per_page',
			'title' => 'Easy Menu Per Page',
			'object_types' => array('page', 'post', 'team', 'portfolio'), // post type
			'context' => 'normal',
			'priority' => 'low',
			'show_names' => true, // Show field names on the left
			'fields' => array(
				array(
				    'name'             => 'Override the menu on this page?',
				    'desc'             => 'Use this option to set a specific menu for this page only.',
				    'id'               => $prefix . 'menu_override',
				    'type'             => 'select',
				    'show_option_none' => true,
				    'default'          => 'none',
				    'options'          => $custom_menus,
				),
			)
		);
				
		return $meta_boxes;
	}
	add_filter( 'cmb2_meta_boxes', 'tommusrhodus_easy_menu_per_page_custom_metaboxes' );
}

/**
 * Custom Comment Markup for Stack
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists('ebor_custom_comment') )){
	function ebor_custom_comment($comment, $args, $depth) { 
		$GLOBALS['comment'] = $comment; 
	?>
		
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
			<div class="clearfix comment-wrap">
			
				<div class="commenter-avatar"> 
					<?php echo get_avatar( $comment->comment_author_email, 52 ); ?>
				</div>
				
				<div class="comment-content"> 
					<span class="small"><?php echo get_comment_date(); ?> <span class="padding">&#183;</span> <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span>
					<?php printf('<h5>%s</h5>', get_comment_author()); ?>
					<?php echo wpautop( get_comment_text() ); ?>
					<?php if ($comment->comment_approved == '0') : ?>
						<p><em><?php esc_html_e('Your comment is awaiting moderation.', 'sugarland') ?></em></p>
					<?php endif; ?>	
				</div>
				
			</div>
		
	<?php }
}